---
name: Bug Report
about: Report a bug to help improve SQLFluff
labels: bug
---

_If this is a parsing or linting issue, please include a minimal SQL example which reproduces the issue, along with the `sqlfluff parse` output, `sqlfluff lint` output and `sqlfluff fix` output when relevant._

## Expected Behaviour

## Observed Behaviour

## Steps to Reproduce

## Dialect

## Version
Include the output of `sqlfluff --version` along with your Python version

## Configuration
```
Include your SQLFluff configuration here
```
